@@ -27,6 +27,7 @@ from socket import socket, error as socketerror
 from logilab.common.testlib import TestCase, unittest_main, mock_object
 from cubicweb.devtools.testlib import CubicWebTC
 from cubicweb.devtools.repotest import RQLGeneratorTC
+from cubicweb.devtools.httptest import get_available_port
 
 from cubicweb.server.sources.ldapuser import *
 
@@ -49,8 +50,7 @@ def nopwd_authenticate(self, session, login, password):
     """
     assert login, 'no login!'
     searchfilter = [filter_format('(%s=%s)', (self.user_login_attr, login))]
-    searchfilter.extend([filter_format('(%s=%s)', ('objectClass', o))
-                         for o in self.user_classes])
+    searchfilter.extend(self.base_filters)
     searchstr = '(&%s)' % ''.join(searchfilter)
     # first search the user
     try:
@@ -88,6 +88,10 @@ def create_slapd_configuration(config):
     global slapd_process, CONFIG
     basedir = join(config.apphome, "ldapdb")
     slapdconf = join(config.apphome, "slapd.conf")
+    confin = file(join(config.apphome, "slapd.conf.in")).read()
+    confstream = file(slapdconf, 'w')
+    confstream.write(confin % {'apphome': config.apphome})
+    confstream.close()
     if not exists(basedir):
         os.makedirs(basedir)
         # fill ldap server with some data
@@ -98,19 +102,7 @@ def create_slapd_configuration(config):
 
 
     #ldapuri = 'ldapi://' + join(basedir, "ldapi").replace('/', '%2f')
-    for port in range(9000, 9100):
-        try:
-            socket().bind(('localhost', port))
-        except socketerror, e:
-            if e.errno == 98: # Address already in use
-                pass
-            else:
-                raise
-        else:
-            break
-    else:
-        raise Exception("Can't find a free TCP port on localhost")
-
+    port = get_available_port(xrange(9000, 9100))
     host = 'localhost:%s' % port
     ldapuri = 'ldap://%s' % host
     cmdline = ["/usr/sbin/slapd", "-f",  slapdconf,  "-h",  ldapuri, "-d", "0"]
@@ -128,7 +120,11 @@ def terminate_slapd():
     global slapd_process
     if slapd_process.returncode is None:
         print "terminating slapd"
-        slapd_process.terminate()
+        if hasattr(slapd_process, 'terminate'):
+            slapd_process.terminate()
+        else:
+            import os, signal
+            os.kill(slapd_process.pid, signal.SIGTERM)
         slapd_process.wait()
         print "DONE"
 
@@ -456,8 +452,7 @@ class RQL2LDAPFilterTC(RQLGeneratorTC):
         self.pool = repo._get_pool()
         session = mock_object(pool=self.pool)
         self.o = RQL2LDAPFilter(ldapsource, session)
-        self.ldapclasses = ''.join('(objectClass=%s)' % ldapcls
-                                   for ldapcls in ldapsource.user_classes)
+        self.ldapclasses = ''.join(ldapsource.base_filters)
 
     def tearDown(self):
         repo._free_pool(self.pool)
