@@ -419,7 +419,7 @@ function removeBookmark(beid) {
     var d = loadRemote('json', ajaxFuncArgs('delete_bookmark', null, beid));
     d.addCallback(function(boxcontent) {
         $('#bookmarks_box').loadxhtml('json',
-                                      ajaxFuncArgs('render', null, 'boxes',
+                                      ajaxFuncArgs('render', null, 'ctxcomponents',
                                                    'bookmarks_box'));
         document.location.hash = '#header';
         updateMessage(_("bookmark has been removed"));
@@ -608,6 +608,29 @@ function reload(domid, compid, registry, formparams  /* ... */) {
     $('#'+domid).loadxhtml('json', params, null, 'swap');
 }
 
+/* ajax tabs ******************************************************************/
+
+function setTab(tabname, cookiename) {
+    // set appropriate cookie
+    loadRemote('json', ajaxFuncArgs('set_cookie', null, cookiename, tabname));
+    // trigger show + tabname event
+    triggerLoad(tabname);
+}
+
+function loadNow(eltsel, holesel, reloadable) {
+    var lazydiv = jQuery(eltsel);
+    var hole = lazydiv.children(holesel);
+    if ((hole.length == 0) && ! reloadable) {
+        /* the hole is already filed */
+        return;
+    }
+    lazydiv.loadxhtml(lazydiv.attr('cubicweb:loadurl'), {'pageid': pageid});
+}
+
+function triggerLoad(divid) {
+    jQuery('#lazy-' + divid).trigger('load_' + divid);
+}
+
 /* DEPRECATED *****************************************************************/
 
 preprocessAjaxLoad = cw.utils.deprecatedFunction(
@@ -633,7 +656,7 @@ reloadComponent = cw.utils.deprecatedFunction(
 reloadBox = cw.utils.deprecatedFunction(
     '[3.9] reloadBox() is deprecated, use loadxhtml instead',
     function(boxid, rql) {
-        return reloadComponent(boxid, rql, 'boxes', boxid);
+        return reloadComponent(boxid, rql, 'ctxcomponents', boxid);
     }
 );
 
