@@ -267,9 +267,9 @@ class InlineEntityEditionFormView(f.FormViewMixIn, EntityView):
             self._cw.data[countkey] += 1
         except KeyError:
             self._cw.data[countkey] = 1
-        self.w(self.form.render(
-            divid=divid, title=title, removejs=removejs, i18nctx=i18nctx,
-            counter=self._cw.data[countkey] , **kwargs))
+        self.form.render(w=self.w, divid=divid, title=title, removejs=removejs,
+                         i18nctx=i18nctx, counter=self._cw.data[countkey] ,
+                         **kwargs)
 
     def form_title(self, entity, i18nctx):
         return self._cw.pgettext(i18nctx, entity.__regid__)
@@ -550,6 +550,7 @@ class GenericRelationsField(ff.Field):
         pending_inserts = set(get_pending_inserts(form._cw, form.edited_entity.eid))
         for pendingid in pending_inserts:
             eidfrom, rtype, eidto = pendingid.split(':')
+            pendingid = 'id' + pendingid
             if typed_eid(eidfrom) == entity.eid: # subject
                 label = display_name(form._cw, rtype, 'subject',
                                      entity.__regid__)
@@ -825,7 +826,8 @@ class AutomaticEntityForm(forms.EntityFieldsForm):
                              'inlined form but there is multiple target types, '
                              'dunno what to do', rschema)
                 continue
-            ttype = ttypes[0].type
+            tschema = ttypes[0]
+            ttype = tschema.type
             formviews = list(self.inline_edition_form_view(rschema, ttype, role))
             card = rschema.role_rdef(entity.e_schema, ttype, role).role_cardinality(role)
             # there is no related entity and we need at least one: we need to
@@ -835,12 +837,22 @@ class AutomaticEntityForm(forms.EntityFieldsForm):
             # we can create more than one related entity, we thus display a link
             # to add new related entities
             if self.should_display_add_new_relation_link(rschema, formviews, card):
-                addnewlink = self._cw.vreg['views'].select(
-                    'inline-addnew-link', self._cw,
-                    etype=ttype, rtype=rschema, role=role, card=card,
-                    peid=self.edited_entity.eid,
-                    petype=self.edited_entity.e_schema, pform=self)
-                formviews.append(addnewlink)
+                rdef = entity.e_schema.rdef(rschema, role, ttype)
+                if entity.has_eid():
+                    if role == 'subject':
+                        rdefkwargs = {'fromeid': entity.eid}
+                    else:
+                        rdefkwargs = {'toeid': entity.eid}
+                else:
+                    rdefkwargs = {}
+                if (tschema.has_perm(self._cw, 'add')
+                    and rdef.has_perm(self._cw, 'add', **rdefkwargs)):
+                    addnewlink = self._cw.vreg['views'].select(
+                        'inline-addnew-link', self._cw,
+                        etype=ttype, rtype=rschema, role=role, card=card,
+                        peid=self.edited_entity.eid,
+                        petype=self.edited_entity.e_schema, pform=self)
+                    formviews.append(addnewlink)
             allformviews += formviews
         return allformviews
 
@@ -858,7 +870,7 @@ class AutomaticEntityForm(forms.EntityFieldsForm):
         by default true if there is no related entity or if the relation has
         multiple cardinality
         """
-        return not existant or card in '+*' # XXX add target type permisssions
+        return not existant or card in '+*'
 
     def should_hide_add_new_relation_link(self, rschema, card):
         """return true if once an inlined creation form is added, the 'add new'
